diff --git a/app/src/main/res/layout-v18/fragment_videoitem_detail.xml b/app/src/main/res/layout-v18/fragment_videoitem_detail.xml
new file mode 100644
index 000000000..91cfea986
--- /dev/null
+++ b/app/src/main/res/layout-v18/fragment_videoitem_detail.xml
@@ -0,0 +1,219 @@
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
\ No newline at end of file
diff --git a/app/src/main/res/layout/fragment_videoitem_detail.xml b/app/src/main/res/layout/fragment_videoitem_detail.xml
index f9a199edd..987c416ec 100644
--- a/app/src/main/res/layout/fragment_videoitem_detail.xml
+++ b/app/src/main/res/layout/fragment_videoitem_detail.xml
@@ -1,6 +1,6 @@
-
-
-
+ android:visibility="visible"
+ tools:ignore="UselessParent">
+
+
-
\ No newline at end of file
+
\ No newline at end of file
diff --git a/app/src/main/res/layout/video_item.xml b/app/src/main/res/layout/video_item.xml
index ef11a8c08..1c7caac60 100644
--- a/app/src/main/res/layout/video_item.xml
+++ b/app/src/main/res/layout/video_item.xml
@@ -28,7 +28,8 @@
+ android:layout_height="wrap_content"
+ tools:ignore="RtlHardcoded">
+ android:layout_toRightOf="@id/itemThumbnailViewContainer"
+ tools:ignore="RtlHardcoded">
diff --git a/app/src/main/res/values-de/strings.xml b/app/src/main/res/values-de/strings.xml
index 4d3a00a06..d17fae7bd 100644
--- a/app/src/main/res/values-de/strings.xml
+++ b/app/src/main/res/values-de/strings.xml
@@ -28,7 +28,6 @@
Kore installierenZeige \"Mit Kodi abspielen\" OptionZeigt eine Option an, über die man Videos mit dem Kodi Mediacenter abspielen kann.
- Play-Button auf der linken Seite.AudioBevorzugtes Audio FormatWebM - freies Format
diff --git a/app/src/main/res/values-es/strings.xml b/app/src/main/res/values-es/strings.xml
index 3c6d1c4b4..bcf25e8fa 100644
--- a/app/src/main/res/values-es/strings.xml
+++ b/app/src/main/res/values-es/strings.xml
@@ -28,7 +28,6 @@
Instalar KoreMostrar la opción \"Reproducir con Kodi\"Muestra una opción para reproducir el vídeo con Kodi media center.
-Mostrar el botón de reproducir en el lado izquierdo.AudioFormato de audio por defectoWebM - formato libre
diff --git a/app/src/main/res/values-fa/strings.xml b/app/src/main/res/values-fa/strings.xml
index 6bee55075..8951a6ee4 100644
--- a/app/src/main/res/values-fa/strings.xml
+++ b/app/src/main/res/values-fa/strings.xml
@@ -28,7 +28,6 @@
نصب Koreنمایش گزینهی «پخش با Kodi»گزینهای برای پخش کردن ویدئو با مرکز رسانهی Kodi نشان میدهد.
- نمایش دکمهی پخش در سمت چپ.صداقالب پیشفرض صداWebM - قالبی آزاد
diff --git a/app/src/main/res/values-fr/strings.xml b/app/src/main/res/values-fr/strings.xml
index 7da59e8d1..6f93c9d13 100644
--- a/app/src/main/res/values-fr/strings.xml
+++ b/app/src/main/res/values-fr/strings.xml
@@ -28,7 +28,6 @@
Mise en ligne le %1$sUtiliser un lecteur externe%1$s vues
- Afficher le bouton de lecture sur la gauche.AudioFormat audio par défautWebM- format libre
diff --git a/app/src/main/res/values-hu/strings.xml b/app/src/main/res/values-hu/strings.xml
index 1aca0c5ad..d6dc6d25f 100644
--- a/app/src/main/res/values-hu/strings.xml
+++ b/app/src/main/res/values-hu/strings.xml
@@ -28,7 +28,6 @@
Kore telepítése\"Lejátszás Kodi-val\" opció mutatásaMutat egy opciót a videók Kodi médiaközponttal való lejátszására
- Lejátszás gomb bal oldalon mutatásaHangAlapértelmezett hang formátumWebM - szabad formátum
diff --git a/app/src/main/res/values-it/strings.xml b/app/src/main/res/values-it/strings.xml
index f33518774..931afc6c2 100644
--- a/app/src/main/res/values-it/strings.xml
+++ b/app/src/main/res/values-it/strings.xml
@@ -27,7 +27,6 @@
Installa KoreMostra l\'opzione \"Riproduci con Kodi\"Mostra un opzione per riprodurre un video attraverso Kodi media center.
- Mostra pulsante di avvio sul lato sinistro.AudioFormato audio predefinitoWedM - formato libero
diff --git a/app/src/main/res/values-ja/strings.xml b/app/src/main/res/values-ja/strings.xml
index f132e4749..dcc657eb4 100644
--- a/app/src/main/res/values-ja/strings.xml
+++ b/app/src/main/res/values-ja/strings.xml
@@ -27,7 +27,6 @@
Kore をインストール\"Kodi で再生\" 設定を表示Kodi メディアセンター経由で動画を再生するための設定を表示します.
- 左側に再生ボタンを表示.オーディオ基本のオーディオフォーマット.WebM - フリーフォーマット
diff --git a/app/src/main/res/values-ko/strings.xml b/app/src/main/res/values-ko/strings.xml
index da2e64970..bdb8b1084 100644
--- a/app/src/main/res/values-ko/strings.xml
+++ b/app/src/main/res/values-ko/strings.xml
@@ -27,7 +27,6 @@
Kore 설치\"Kodi로 재생\" 옵션 표시비디오를 Kodi media center를 사용해 재생하는 옵션을 표시합니다.
- 재생 버튼을 왼쪽에 표시합니다.오디오기본 오디오 포맷WebM - 무료 자유 포맷입니다
diff --git a/app/src/main/res/values-nl/strings.xml b/app/src/main/res/values-nl/strings.xml
index b3bf12381..8fa79cb59 100644
--- a/app/src/main/res/values-nl/strings.xml
+++ b/app/src/main/res/values-nl/strings.xml
@@ -28,7 +28,6 @@
Installeer KoreToon \"Speel af met Kodi\" optieToont een optie om een video op een Kodi media center af te spelen.
- Afspeel knop aan de linker kant weergeven.AudioStandaard audio formaatWebam - open formaat
diff --git a/app/src/main/res/values-pl/strings.xml b/app/src/main/res/values-pl/strings.xml
index 54a7ce0ad..46e5b3c9b 100644
--- a/app/src/main/res/values-pl/strings.xml
+++ b/app/src/main/res/values-pl/strings.xml
@@ -25,7 +25,6 @@
Zainstaluj KoreWyświetlaj opcję \"Odtwarzaj za pośrednictwem Kodi\"Wyświetla opcję do odtwarzania wideo przez aplikację Kodi.
- Wyświetl przycisk odtwarzania po lewej stronie.DźwiękDomyślny format dźwiękuWebM - otwarty format
diff --git a/app/src/main/res/values-ru/strings.xml b/app/src/main/res/values-ru/strings.xml
index 798c4f09b..a2dbdd50f 100644
--- a/app/src/main/res/values-ru/strings.xml
+++ b/app/src/main/res/values-ru/strings.xml
@@ -28,7 +28,6 @@
Установить KoreПоказывать опцию \"Воспроизвести с помощью Kodi\"Показать опцию воспроизведения видео через Kodi media center.
- Показать кнопку воспроизведения слева.АудиоФормат аудио по-умолчаниюWebM - свободный формат
diff --git a/app/src/main/res/values-sr/strings.xml b/app/src/main/res/values-sr/strings.xml
index 726ba9abe..2e72a4db5 100644
--- a/app/src/main/res/values-sr/strings.xml
+++ b/app/src/main/res/values-sr/strings.xml
@@ -28,7 +28,6 @@
Инсталирај КорПрикажи „Пусти помоћу Кодија“Приказ опције за пуштање видеа у Коди медија центру.
- Прикажи дугме за пуштање на левој страни.АудиоПодразумевани формат звукаWebM - слободни формат
diff --git a/app/src/main/res/values/colors.xml b/app/src/main/res/values/colors.xml
index a35724980..e14ee9606 100644
--- a/app/src/main/res/values/colors.xml
+++ b/app/src/main/res/values/colors.xml
@@ -6,6 +6,5 @@
#a000#efff#6000
- #222#EEEEEE
\ No newline at end of file
diff --git a/app/src/main/res/values/settings_keys.xml b/app/src/main/res/values/settings_keys.xml
index f1cd7ebaf..f7c6020a6 100644
--- a/app/src/main/res/values/settings_keys.xml
+++ b/app/src/main/res/values/settings_keys.xml
@@ -17,7 +17,6 @@
360pshow_play_with_kodi_preference
- left_hand_layoutdefault_audio_format@string/webMAudioDescription
diff --git a/app/src/main/res/values/strings.xml b/app/src/main/res/values/strings.xml
index d93baf845..c819f5ff7 100644
--- a/app/src/main/res/values/strings.xml
+++ b/app/src/main/res/values/strings.xml
@@ -32,7 +32,6 @@
https://f-droid.org/repository/browse/?fdfilter=Kore&fdid=org.xbmc.koreShow \"Play with Kodi\" optionDisplays an option to play a video via Kodi media center.
- Show play button on the left side.AudioDefault audio formatWebM - free format
diff --git a/app/src/main/res/xml/settings_screen.xml b/app/src/main/res/xml/settings_screen.xml
index 59ed1b28f..724c27e99 100644
--- a/app/src/main/res/xml/settings_screen.xml
+++ b/app/src/main/res/xml/settings_screen.xml
@@ -37,11 +37,6 @@
android:summary="@string/showPlayWithKodiSummary"
android:defaultValue="false" />
-
-
diff --git a/app/src/main/java/org/schabi/newpipe/VideoItemDetailFragment.java b/app/src/main/java/org/schabi/newpipe/VideoItemDetailFragment.java
index a7c80bea6..4290e5c9c 100644
--- a/app/src/main/java/org/schabi/newpipe/VideoItemDetailFragment.java
+++ b/app/src/main/java/org/schabi/newpipe/VideoItemDetailFragment.java
@@ -8,6 +8,7 @@ import android.content.res.Resources;
import android.graphics.Bitmap;
import android.graphics.BitmapFactory;
import android.graphics.Point;
+import android.os.Build;
import android.os.Bundle;
import android.os.Handler;
import android.preference.PreferenceManager;
@@ -379,20 +380,6 @@ public class VideoItemDetailFragment extends Fragment {
e.printStackTrace();
}
- if (PreferenceManager.getDefaultSharedPreferences(getActivity())
- .getBoolean(getString(R.string.leftHandLayout), false) && checkIfLandscape()) {
- RelativeLayout.LayoutParams oldLayout =
- (RelativeLayout.LayoutParams) playVideoButton.getLayoutParams();
- RelativeLayout.LayoutParams layoutParams = new RelativeLayout.LayoutParams(
- RelativeLayout.LayoutParams.WRAP_CONTENT,
- RelativeLayout.LayoutParams.WRAP_CONTENT);
- layoutParams.addRule(RelativeLayout.ALIGN_PARENT_BOTTOM);
- layoutParams.addRule(RelativeLayout.ALIGN_PARENT_LEFT);
- layoutParams.setMargins(oldLayout.leftMargin, oldLayout.topMargin,
- oldLayout.rightMargin, oldLayout.bottomMargin);
- playVideoButton.setLayoutParams(layoutParams);
- }
-
playVideoButton.setOnClickListener(new View.OnClickListener() {
@Override
public void onClick(View v) {
@@ -422,22 +409,26 @@ public class VideoItemDetailFragment extends Fragment {
}
});
- ImageView thumbnailView = (ImageView) activity.findViewById(R.id.detailThumbnailView);
- thumbnailView.addOnLayoutChangeListener(new View.OnLayoutChangeListener() {
- // This is used to synchronize the thumbnailWindowButton and the playVideoButton
- // inside the ScrollView with the actual size of the thumbnail.
- @Override
- public void onLayoutChange(View v, int left, int top, int right, int bottom, int oldLeft, int oldTop, int oldRight, int oldBottom) {
- RelativeLayout.LayoutParams newWindowLayoutParams =
- (RelativeLayout.LayoutParams) thumbnailWindowLayout.getLayoutParams();
- newWindowLayoutParams.height = bottom - top;
- thumbnailWindowLayout.setLayoutParams(newWindowLayoutParams);
+ // todo: Fix this workaround (probably with a better design), so that older android
+ // versions don't have problems rendering the thumbnail right.
+ if(Build.VERSION.SDK_INT >= 18) {
+ ImageView thumbnailView = (ImageView) activity.findViewById(R.id.detailThumbnailView);
+ thumbnailView.addOnLayoutChangeListener(new View.OnLayoutChangeListener() {
+ // This is used to synchronize the thumbnailWindowButton and the playVideoButton
+ // inside the ScrollView with the actual size of the thumbnail.
+ @Override
+ public void onLayoutChange(View v, int left, int top, int right, int bottom, int oldLeft, int oldTop, int oldRight, int oldBottom) {
+ RelativeLayout.LayoutParams newWindowLayoutParams =
+ (RelativeLayout.LayoutParams) thumbnailWindowLayout.getLayoutParams();
+ newWindowLayoutParams.height = bottom - top;
+ thumbnailWindowLayout.setLayoutParams(newWindowLayoutParams);
- //noinspection SuspiciousNameCombination
- initialThumbnailPos.set(top, left);
+ //noinspection SuspiciousNameCombination
+ initialThumbnailPos.set(top, left);
- }
- });
+ }
+ });
+ }
}
}